@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Manages all providers."""
+
 from __future__ import annotations
 
 import fnmatch
@@ -84,6 +85,8 @@ def _ensure_prefix_for_placeholders(field_behaviors: dict[str, Any], conn_type:
 
 
 if TYPE_CHECKING:
+    from urllib.parse import SplitResult
+
     from airflow.decorators.base import TaskDecorator
     from airflow.hooks.base import BaseHook
     from airflow.typing_compat import Literal
@@ -146,7 +149,7 @@ def _read_schema_from_resources_or_local_file(filename: str) -> dict:
 
 
 def _create_provider_info_schema_validator():
-    """Creates JSON schema validator from the provider_info.schema.json."""
+    """Create JSON schema validator from the provider_info.schema.json."""
     import jsonschema
 
     schema = _read_schema_from_resources_or_local_file("provider_info.schema.json")
@@ -156,7 +159,7 @@ def _create_provider_info_schema_validator():
 
 
 def _create_customized_form_field_behaviours_schema_validator():
-    """Creates JSON schema validator from the customized_form_field_behaviours.schema.json."""
+    """Create JSON schema validator from the customized_form_field_behaviours.schema.json."""
     import jsonschema
 
     schema = _read_schema_from_resources_or_local_file("customized_form_field_behaviours.schema.json")
@@ -301,11 +304,9 @@ def log_import_warning(class_name, e, provider_package):
 KNOWN_UNHANDLED_OPTIONAL_FEATURE_ERRORS = [("apache-airflow-providers-google", "No module named 'paramiko'")]
 
 
-def _correctness_check(
-    provider_package: str, class_name: str, provider_info: ProviderInfo
-) -> type[BaseHook] | None:
+def _correctness_check(provider_package: str, class_name: str, provider_info: ProviderInfo) -> Any:
     """
-    Performs coherence check on provider classes.
+    Perform coherence check on provider classes.
 
     For apache-airflow providers - it checks if it starts with appropriate package. For all providers
     it tries to import the provider - checking that there are no exceptions during importing.
@@ -408,7 +409,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         return ProvidersManager._initialization_stack_trace
 
     def __init__(self):
-        """Initializes the manager."""
+        """Initialize the manager."""
         super().__init__()
         ProvidersManager._initialized = True
         ProvidersManager._initialization_stack_trace = "".join(traceback.format_stack(inspect.currentframe()))
@@ -418,6 +419,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         # Keeps dict of hooks keyed by connection type
         self._hooks_dict: dict[str, HookInfo] = {}
         self._fs_set: set[str] = set()
+        self._dataset_uri_handlers: dict[str, Callable[[SplitResult], SplitResult]] = {}
         self._taskflow_decorators: dict[str, Callable] = LazyDictWithCache()  # type: ignore[assignment]
         # keeps mapping between connection_types and hook class, package they come from
         self._hook_provider_dict: dict[str, HookClassProvider] = {}
@@ -429,6 +431,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self._field_behaviours: dict[str, dict] = {}
         self._extra_link_class_name_set: set[str] = set()
         self._logging_class_name_set: set[str] = set()
+        self._auth_manager_class_name_set: set[str] = set()
         self._secrets_backend_class_name_set: set[str] = set()
         self._executor_class_name_set: set[str] = set()
         self._provider_configs: dict[str, dict[str, Any]] = {}
@@ -444,7 +447,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self._init_airflow_core_hooks()
 
     def _init_airflow_core_hooks(self):
-        """Initializes the hooks dict with default hooks from Airflow core."""
+        """Initialize the hooks dict with default hooks from Airflow core."""
         core_dummy_hooks = {
             "generic": "Generic",
             "email": "Email",
@@ -513,6 +516,12 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self.initialize_providers_list()
         self._discover_filesystems()
 
+    @provider_info_cache("dataset_uris")
+    def initializa_providers_dataset_uri_handlers(self):
+        """Lazy initialization of provider dataset URI handlers."""
+        self.initialize_providers_list()
+        self._discover_dataset_uri_handlers()
+
     @provider_info_cache("taskflow_decorators")
     def initialize_providers_taskflow_decorator(self):
         """Lazy initialization of providers hooks."""
@@ -549,6 +558,12 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self.initialize_providers_list()
         self._discover_notifications()
 
+    @provider_info_cache("auth_managers")
+    def initialize_providers_auth_managers(self):
+        """Lazy initialization of providers notifications information."""
+        self.initialize_providers_list()
+        self._discover_auth_managers()
+
     @provider_info_cache("config")
     def initialize_providers_configuration(self):
         """Lazy initialization of providers configuration information."""
@@ -556,7 +571,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
 
     def _initialize_providers_configuration(self):
         """
-        Internal method to initialize providers configuration information.
+        Initialize providers configuration information.
 
         Should be used if we do not want to trigger caching for ``initialize_providers_configuration`` method.
         In some cases we might want to make sure that the configuration is initialized, but we do not want
@@ -604,7 +619,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
             self._provider_schema_validator.validate(provider_info)
             provider_info_package_name = provider_info["package-name"]
             if package_name != provider_info_package_name:
-                raise Exception(
+                raise ValueError(
                     f"The package '{package_name}' from setuptools and "
                     f"{provider_info_package_name} do not match. Please make sure they are aligned"
                 )
@@ -619,7 +634,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
 
     def _discover_all_airflow_builtin_providers_from_local_sources(self) -> None:
         """
-        Finds all built-in airflow providers if airflow is run from the local sources.
+        Find all built-in airflow providers if airflow is run from the local sources.
 
         It finds `provider.yaml` files for all such providers and registers the providers using those.
 
@@ -643,11 +658,11 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                     seen.add(path)
                     self._add_provider_info_from_local_source_files_on_path(path)
             except Exception as e:
-                log.warning(f"Error when loading 'provider.yaml' files from {path} airflow sources: {e}")
+                log.warning("Error when loading 'provider.yaml' files from %s airflow sources: %s", path, e)
 
     def _add_provider_info_from_local_source_files_on_path(self, path) -> None:
         """
-        Finds all the provider.yaml files in the directory specified.
+        Find all the provider.yaml files in the directory specified.
 
         :param path: path where to look for provider.yaml files
         """
@@ -665,7 +680,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
 
     def _add_provider_info_from_local_source_file(self, path, package_name) -> None:
         """
-        Parses found provider.yaml file and adds found provider to the dictionary.
+        Parse found provider.yaml file and adds found provider to the dictionary.
 
         :param path: full file path of the provider.yaml file
         :param package_name: name of the package
@@ -852,10 +867,26 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         """Retrieve all filesystems defined in the providers."""
         for provider_package, provider in self._provider_dict.items():
             for fs_module_name in provider.data.get("filesystems", []):
-                if _correctness_check(provider_package, fs_module_name + ".get_fs", provider):
+                if _correctness_check(provider_package, f"{fs_module_name}.get_fs", provider):
                     self._fs_set.add(fs_module_name)
         self._fs_set = set(sorted(self._fs_set))
 
+    def _discover_dataset_uri_handlers(self) -> None:
+        from airflow.datasets import normalize_noop
+
+        for provider_package, provider in self._provider_dict.items():
+            for handler_info in provider.data.get("dataset-uris", []):
+                try:
+                    schemes = handler_info["schemes"]
+                    handler_path = handler_info["handler"]
+                except KeyError:
+                    continue
+                if handler_path is None:
+                    handler = normalize_noop
+                elif not (handler := _correctness_check(provider_package, handler_path, provider)):
+                    continue
+                self._dataset_uri_handlers.update((scheme, handler) for scheme in schemes)
+
     def _discover_taskflow_decorators(self) -> None:
         for name, info in self._provider_dict.items():
             for taskflow_decorator in info.data.get("task-decorators", []):
@@ -932,7 +963,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                     f"Provider package name is not set when hook_class_name ({hook_class_name}) is used"
                 )
         allowed_field_classes = [IntegerField, PasswordField, StringField, BooleanField]
-        hook_class = _correctness_check(package_name, hook_class_name, provider_info)
+        hook_class: type[BaseHook] | None = _correctness_check(package_name, hook_class_name, provider_info)
         if hook_class is None:
             return None
         try:
@@ -1061,8 +1092,16 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                 e,
             )
 
+    def _discover_auth_managers(self) -> None:
+        """Retrieve all auth managers defined in the providers."""
+        for provider_package, provider in self._provider_dict.items():
+            if provider.data.get("auth-managers"):
+                for auth_manager_class_name in provider.data["auth-managers"]:
+                    if _correctness_check(provider_package, auth_manager_class_name, provider):
+                        self._auth_manager_class_name_set.add(auth_manager_class_name)
+
     def _discover_notifications(self) -> None:
-        """Retrieves all notifications defined in the providers."""
+        """Retrieve all notifications defined in the providers."""
         for provider_package, provider in self._provider_dict.items():
             if provider.data.get("notifications"):
                 for notification_class_name in provider.data["notifications"]:
@@ -1070,7 +1109,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                         self._notification_info_set.add(notification_class_name)
 
     def _discover_extra_links(self) -> None:
-        """Retrieves all extra links defined in the providers."""
+        """Retrieve all extra links defined in the providers."""
         for provider_package, provider in self._provider_dict.items():
             if provider.data.get("extra-links"):
                 for extra_link_class_name in provider.data["extra-links"]:
@@ -1113,9 +1152,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         """Retrieve all configs defined in the providers."""
         for provider_package, provider in self._provider_dict.items():
             if provider.data.get("config"):
-                self._provider_configs[provider_package] = (
-                    provider.data.get("config")  # type: ignore[assignment]
-                )
+                self._provider_configs[provider_package] = provider.data.get("config")  # type: ignore[assignment]
 
     def _discover_plugins(self) -> None:
         """Retrieve all plugins defined in the providers."""
@@ -1134,7 +1171,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
 
     @provider_info_cache("triggers")
     def initialize_providers_triggers(self):
-        """Initialization of providers triggers."""
+        """Initialize providers triggers."""
         self.initialize_providers_list()
         for provider_package, provider in self._provider_dict.items():
             for trigger in provider.data.get("triggers", []):
@@ -1147,6 +1184,12 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                         )
                     )
 
+    @property
+    def auth_managers(self) -> list[str]:
+        """Returns information about available providers notifications class."""
+        self.initialize_providers_auth_managers()
+        return sorted(self._auth_manager_class_name_set)
+
     @property
     def notification(self) -> list[NotificationInfo]:
         """Returns information about available providers notifications class."""
@@ -1239,6 +1282,11 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self.initialize_providers_filesystems()
         return sorted(self._fs_set)
 
+    @property
+    def dataset_uri_handlers(self) -> dict[str, Callable[[SplitResult], SplitResult]]:
+        self.initializa_providers_dataset_uri_handlers()
+        return self._dataset_uri_handlers
+
     @property
     def provider_configs(self) -> list[tuple[str, dict[str, Any]]]:
         self.initialize_providers_configuration()
@@ -1260,6 +1308,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self._field_behaviours.clear()
         self._extra_link_class_name_set.clear()
         self._logging_class_name_set.clear()
+        self._auth_manager_class_name_set.clear()
         self._secrets_backend_class_name_set.clear()
         self._executor_class_name_set.clear()
         self._provider_configs.clear()
