@@ -90,6 +90,7 @@ _REVISION_HEADS_MAP = {
     "2.7.0": "405de8318b3a",
     "2.8.0": "10b52ebd31f7",
     "2.8.1": "88344c1d9134",
+    "2.9.0": "1949afb29106",
 }
 
 
@@ -137,6 +138,13 @@ def create_default_connections(session: Session = NEW_SESSION):
         ),
         session,
     )
+    merge_conn(
+        Connection(
+            conn_id="athena_default",
+            conn_type="athena",
+        ),
+        session,
+    )
     merge_conn(
         Connection(
             conn_id="aws_default",
@@ -534,6 +542,15 @@ def create_default_connections(session: Session = NEW_SESSION):
         ),
         session,
     )
+    merge_conn(
+        Connection(
+            conn_id="qdrant_default",
+            conn_type="qdrant",
+            host="qdrant",
+            port=6333,
+        ),
+        session,
+    )
     merge_conn(
         Connection(
             conn_id="redis_default",
@@ -606,14 +623,6 @@ def create_default_connections(session: Session = NEW_SESSION):
         ),
         session,
     )
-    merge_conn(
-        Connection(
-            conn_id="sqoop_default",
-            conn_type="sqoop",
-            host="rdbms",
-        ),
-        session,
-    )
     merge_conn(
         Connection(
             conn_id="ssh_default",
@@ -641,6 +650,17 @@ def create_default_connections(session: Session = NEW_SESSION):
         ),
         session,
     )
+    merge_conn(
+        Connection(
+            conn_id="teradata_default",
+            conn_type="teradata",
+            host="localhost",
+            login="user",
+            password="password",
+            schema="schema",
+        ),
+        session,
+    )
     merge_conn(
         Connection(
             conn_id="trino_default",
@@ -704,8 +724,8 @@ def _get_flask_db(sql_database_uri):
 def _create_db_from_orm(session):
     from alembic import command
 
-    from airflow.auth.managers.fab.models import Model
     from airflow.models.base import Base
+    from airflow.providers.fab.auth_manager.models import Model
 
     def _create_flask_session_tbl(sql_database_uri):
         db = _get_flask_db(sql_database_uri)
@@ -952,6 +972,33 @@ def synchronize_log_template(*, session: Session = NEW_SESSION) -> None:
         session.add(LogTemplate(filename=filename, elasticsearch_id=elasticsearch_id))
 
 
+def encrypt_trigger_kwargs(*, session: Session) -> None:
+    """Encrypt trigger kwargs."""
+    from airflow.models.trigger import Trigger
+    from airflow.serialization.serialized_objects import BaseSerialization
+
+    for trigger in session.query(Trigger):
+        # convert serialized dict to string and encrypt it
+        trigger.kwargs = BaseSerialization.deserialize(json.loads(trigger.encrypted_kwargs))
+    session.commit()
+
+
+def decrypt_trigger_kwargs(*, session: Session) -> None:
+    """Decrypt trigger kwargs."""
+    from airflow.models.trigger import Trigger
+    from airflow.serialization.serialized_objects import BaseSerialization
+
+    if not inspect(session.bind).has_table(Trigger.__tablename__):
+        # table does not exist, nothing to do
+        # this can happen when we downgrade to an old version before the Trigger table was added
+        return
+
+    for trigger in session.scalars(select(Trigger.encrypted_kwargs)):
+        # decrypt the string and convert it to serialized dict
+        trigger.encrypted_kwargs = json.dumps(BaseSerialization.serialize(trigger.kwargs))
+    session.commit()
+
+
 def check_conn_id_duplicates(session: Session) -> Iterable[str]:
     """
     Check unique conn_id in connection table.
@@ -984,7 +1031,7 @@ def check_username_duplicates(session: Session) -> Iterable[str]:
     :param session:  session of the sqlalchemy
     :rtype: str
     """
-    from airflow.auth.managers.fab.models import RegisterUser, User
+    from airflow.providers.fab.auth_manager.models import RegisterUser, User
 
     for model in [User, RegisterUser]:
         dups = []
@@ -1185,18 +1232,7 @@ def _create_table_as(
 
     We have to handle CTAS differently for different dialects.
     """
-    from sqlalchemy import column, select, table
-
-    if dialect_name == "mssql":
-        cte = source_query.cte("source")
-        moved_data_tbl = table(target_table_name, *(column(c.name) for c in cte.columns))
-        ins = moved_data_tbl.insert().from_select(list(cte.columns), select(cte))
-
-        stmt = ins.compile(bind=session.get_bind())
-        cte_sql = stmt.ctes[cte]
-
-        session.execute(text(f"WITH {cte_sql} SELECT source.* INTO {target_table_name} FROM source"))
-    elif dialect_name == "mysql":
+    if dialect_name == "mysql":
         # MySQL with replication needs this split in to two queries, so just do it for all MySQL
         # ERROR 1786 (HY000): Statement violates GTID consistency: CREATE TABLE ... SELECT.
         session.execute(text(f"CREATE TABLE {target_table_name} LIKE {source_table_name}"))
@@ -1480,8 +1516,6 @@ def _check_migration_errors(session: Session = NEW_SESSION) -> Iterable[str]:
     for check_fn in check_functions:
         log.debug("running check function %s", check_fn.__name__)
         yield from check_fn(session=session)
-        # Ensure there is no "active" transaction. Seems odd, but without this MSSQL can hang
-        session.commit()
 
 
 def _offline_migration(migration_func: Callable, config, revision):
@@ -1632,6 +1666,12 @@ def upgradedb(
         _reserialize_dags(session=session)
     add_default_pool_if_not_exists(session=session)
     synchronize_log_template(session=session)
+    if _revision_greater(
+        config,
+        _REVISION_HEADS_MAP["2.9.0"],
+        _get_current_revision(session=session),
+    ):
+        encrypt_trigger_kwargs(session=session)
 
 
 @provide_session
@@ -1704,6 +1744,12 @@ def downgrade(*, to_revision, from_revision=None, show_sql_only=False, session:
         else:
             log.info("Applying downgrade migrations.")
             command.downgrade(config, revision=to_revision, sql=show_sql_only)
+            if _revision_greater(
+                config,
+                _REVISION_HEADS_MAP["2.9.0"],
+                to_revision,
+            ):
+                decrypt_trigger_kwargs(session=session)
 
 
 def drop_airflow_models(connection):
@@ -1713,8 +1759,8 @@ def drop_airflow_models(connection):
     :param connection: SQLAlchemy Connection
     :return: None
     """
-    from airflow.auth.managers.fab.models import Model
     from airflow.models.base import Base
+    from airflow.providers.fab.auth_manager.models import Model
 
     Base.metadata.drop_all(connection)
     Model.metadata.drop_all(connection)
@@ -1782,9 +1828,6 @@ def create_global_lock(
             conn.execute(text("SELECT pg_advisory_lock(:id)"), {"id": lock.value})
         elif dialect.name == "mysql" and dialect.server_version_info >= (5, 6):
             conn.execute(text("SELECT GET_LOCK(:id, :timeout)"), {"id": str(lock), "timeout": lock_timeout})
-        elif dialect.name == "mssql":
-            # TODO: make locking work for MSSQL
-            pass
 
         yield
     finally:
@@ -1795,9 +1838,6 @@ def create_global_lock(
                 raise RuntimeError("Error releasing DB lock!")
         elif dialect.name == "mysql" and dialect.server_version_info >= (5, 6):
             conn.execute(text("select RELEASE_LOCK(:id)"), {"id": str(lock)})
-        elif dialect.name == "mssql":
-            # TODO: make locking work for MSSQL
-            pass
 
 
 def compare_type(context, inspected_column, metadata_column, inspected_type, metadata_type):
@@ -1832,9 +1872,6 @@ def compare_server_default(
     return True if the defaults are different, False if not, or None to allow the default implementation
     to compare these defaults
 
-    Comparing server_default is not accurate in MSSQL because the
-    inspected_default above != metadata_default, while in Postgres/MySQL they are equal.
-    This is an issue with alembic
     In SQLite: task_instance.map_index & task_reschedule.map_index
     are not comparing accurately. Sometimes they are equal, sometimes they are not.
     Alembic warned that this feature has varied accuracy depending on backends.
@@ -1842,7 +1879,7 @@ def compare_server_default(
         environment.EnvironmentContext.configure.params.compare_server_default)
     """
     dialect_name = context.connection.dialect.name
-    if dialect_name in ["mssql", "sqlite"]:
+    if dialect_name in ["sqlite"]:
         return False
     if (
         dialect_name == "mysql"
